@@ -1,6 +1,8 @@
 from scipy.io import readsav
 import matplotlib.dates as mdates
-from lofarSun.lofarJ2000xySun import j2000xy
+import matplotlib as mpl
+
+from lofarSun.lofarJ2000xySun from j2000xy
 import datetime
 import glob
 import os
@@ -27,6 +29,9 @@ import scipy
 import scipy.ndimage
 from matplotlib.patches import Ellipse
 
+
+mpl.rcParams['date.epoch']="0000-12-31T00:00:00"
+
 class LofarDataBF:
     def __init__(self):
         self.fname = ''
@@ -104,8 +109,8 @@ class LofarDataBF:
     def bf_image_by_freq_time(self,freq,time,fov=3000,asecpix=20,extrap=True,interpm='cubic'):
         t_idx_select = (np.abs(self.time_ds - time)).argmin()
         f_idx_select = (np.abs(self.freqs_ds - freq)).argmin()
-        X,Y,data_bf = self.bf_image_by_idx(self,f_idx_select,t_idx_select,fov=fov,asecpix=asecpix,extrap=extrap,interpm=interpm)
-        return [X,Y,data_bf]
+        X,Y,data_bf,x,y,Ibeam = self.bf_image_by_idx(f_idx_select,t_idx_select,fov=fov,asecpix=asecpix,extrap=extrap,interpm=interpm)
+        return [X,Y,data_bf,x,y,Ibeam]
 
     def bf_time_to_idx(self,time):
         return (np.abs(self.time_ds - time)).argmin()
@@ -369,6 +374,7 @@ class LofarDataCleaned:
 
     def make_map(self):
         # still in beta version, use with caution
+        # ref : https://gist.github.com/hayesla/42596c72ab686171fe516f9ab43300e2
         hdu = fits.open(self.fname)
         header = hdu[0].header
         data = np.squeeze(hdu[0].data)
@@ -380,7 +386,7 @@ class LofarDataCleaned:
                            obstime=obstime,
                            distance=sun_coord.earth_distance(obstime),
                            equinox='J2000')
-        lofar_loc = EarthLocation(lat=52.905329712*u.deg, lon=6.867996528*u.deg)
+        lofar_loc = EarthLocation(lat=52.905329712*u.deg, lon=6.867996528*u.deg) # location of the center of LOFAR
         lofar_coord = SkyCoord(lofar_loc.get_itrs(Time(obstime)))
         reference_coord_arcsec = reference_coord.transform_to(frames.Helioprojective(observer=lofar_coord))
         cdelt1 = (np.abs(header['cdelt1'])*u.deg).to(u.arcsec)
@@ -397,7 +403,6 @@ class LofarDataCleaned:
         bl = SkyCoord(-2500*u.arcsec, -2500*u.arcsec, frame=lofar_map_rotate.coordinate_frame)
         tr = SkyCoord(2500*u.arcsec, 2500*u.arcsec, frame=lofar_map_rotate.coordinate_frame)
         lofar_submap = lofar_map_rotate.submap(bl, tr)
-                
         return lofar_submap
 
 
